@@ -2,7 +2,7 @@
 
 import multiprocessing
 import os
-from typing import Tuple, Union
+from typing import Sequence, Tuple, Union
 
 import morecantile
 from rasterio.crs import CRS
@@ -10,6 +10,8 @@ from rasterio.crs import CRS
 NumType = Union[float, int]
 BBox = Tuple[float, float, float, float]
 ColorTuple = Tuple[int, int, int, int]
+NoData = Union[float, int, str]
+Indexes = Union[Sequence[int], int]
 
 MAX_THREADS = int(os.environ.get("MAX_THREADS", multiprocessing.cpu_count() * 5))
 
