@@ -1,5 +1,6 @@
 """rio_tiler.utils: utility functions."""
 
+import os
 from io import BytesIO
 from typing import Any, Dict, Generator, Optional, Sequence, Tuple, Union
 
@@ -36,11 +37,13 @@ def aws_get_object(
     """AWS s3 get object content."""
     if not client:
         session = boto3_session()
-        client = session.client("s3")
+        endpoint_url = os.environ.get("AWS_S3_ENDPOINT", None)
+        client = session.client("s3", endpoint_url=endpoint_url)
 
     params = {"Bucket": bucket, "Key": key}
-    if request_pays:
+    if request_pays or os.environ.get("AWS_REQUEST_PAYER", "").lower() == "requester":
         params["RequestPayer"] = "requester"
+
     response = client.get_object(**params)
     return response["Body"].read()
 
@@ -81,7 +84,7 @@ def _stats(
         max=arr.max().item(),
         std=arr.std().item(),
         histogram=[sample.tolist(), edges.tolist()],
-        valid_percent=numpy.count_nonzero(~arr.mask) / float(arr.data.size),
+        valid_percent=((numpy.count_nonzero(~arr.mask)) / float(arr.data.size)) * 100,
     )
 
 
@@ -341,6 +344,9 @@ def render(
     if img_format == "WEBP" and data.shape[0] == 1:
         data = numpy.repeat(data, 3, axis=0)
 
+    if img_format == "PNG" and data.dtype == "uint16" and mask is not None:
+        mask = linear_rescale(mask, (0, 255), (0, 65535)).astype("uint16")
+
     elif img_format == "JPEG":
         mask = None
 
